@@ -2,7 +2,7 @@ package Config::IniFiles;
 
 use vars qw($VERSION);
 
-$VERSION = '2.75';
+$VERSION = '2.82';
 
 require 5.004;
 use strict;
@@ -255,7 +255,7 @@ syntax.
 
 =item I<-allowempty> 0|1
 
-If set to 1, then empty files are allowed at L</ReadConfig|ReadConfig()>
+If set to 1, then empty files are allowed at L<ReadConfig|ReadConfig()>
 time. If set to 0 (the default), an empty configuration file is considered
 an error.
 
@@ -276,7 +276,7 @@ or
 If set to 0 (the default if not importing), these comments are treated
 like ordinary ones.
 
-The L</WriteConfig|WriteConfig(-delta=>1)> form will output such
+The L<WriteConfig|WriteConfig($filename, -delta=>1)> form will output such
 comments to indicate deleted sections or parameters. This way,
 reloading a delta file using the same imported object produces the
 same results in memory again. See L<IMPORT / DELTA FEATURES> for more
@@ -825,7 +825,9 @@ sub _no_filename
 {
     my $self = shift;
 
-    return not length $self->{cf};
+    my $fn = $self->{cf};
+
+    return (not (defined($fn) && length($fn)));
 }
 
 sub _read_line_num
@@ -1233,7 +1235,7 @@ sub ReadConfig
     $self->{mysects} = []; # A pair of hashes to remember which params are loaded
     $self->{myparms} = {}; # or set using the API vs. imported - useful for
     $self->{peCMT}  = {};  # this will store trailing comments at the end of single-lined params
-    # import shadowing, see below, and WriteConfig(-delta=>1)
+    # import shadowing, see below, and WriteConfig($fn, -delta=>1)
 
     if( defined $self->{imported} ) {
         # Run up the import tree to the top, then reload coming
@@ -1451,6 +1453,61 @@ sub DeleteSection {
     return 1;
 } # end DeleteSection
 
+=head2 RenameSection ( $old_section_name, $new_section_name, $include_groupmembers)
+
+Renames a section if it does not already exists optionally including groupmembers
+
+=cut
+
+sub RenameSection {
+    my $self = shift;
+    my $old_sect = shift;
+    my $new_sect = shift;
+    my $include_groupmembers = shift;
+    return undef unless $self->CopySection($old_sect,$new_sect,$include_groupmembers);
+    return $self->DeleteSection($old_sect);
+
+} # end RenameSection
+
+=head2 CopySection ( $old_section_name, $new_section_name, $include_groupmembers)
+
+Copies one section to another optionally including groupmembers
+
+=cut
+
+sub CopySection {
+    my $self = shift;
+    my $old_sect = shift;
+    my $new_sect = shift;
+    my $include_groupmembers = shift;
+
+    if (not defined $old_sect or
+        not defined $new_sect or
+        !$self->SectionExists($old_sect) or
+        $self->SectionExists($new_sect)) {
+        return undef;
+    }
+
+    $self->_caseify(\$new_sect);
+    $self->_AddSection_Helper($new_sect);
+
+    # This is done the fast way, change if data structure changes!!
+    foreach my $key (qw(v sCMT pCMT EOT parms myparms)) {
+        next unless exists $self->{$key}{$old_sect};
+        $self->{$key}{$new_sect} = Config::IniFiles::_deepcopy($self->{$key}{$old_sect});
+    }
+
+    if($include_groupmembers) {
+        foreach my $old_groupmember ($self->GroupMembers($old_sect)) {
+            my $new_groupmember = $old_groupmember;
+            $new_groupmember =~ s/\A\Q$old_sect\E/$new_sect/;
+            $self->CopySection($old_groupmember,$new_groupmember);
+        }
+    }
+
+    return 1;
+} # end CopySection
+
 =head2 Parameters ($sect_name)
 
 Returns an array containing the parameters contained in the specified
@@ -1642,8 +1699,8 @@ sub GetWriteMode
 =head2 WriteConfig ($filename [, %options])
 
 Writes out a new copy of the configuration file.  A temporary file
-(ending in '-new') is written out and then renamed to the specified
-filename.  Also see B<BUGS> below.
+is written out and then renamed to the specified filename.  Also see
+B<BUGS> below.
 
 If C<-delta> is set to a true value in %options, and this object was
 imported from another (see L</new>), only the differences between this
@@ -1687,7 +1744,7 @@ sub _write_config_to_filename
 
         # Convert the filehandle to a "text" filehandle suitable for use
         # on Windows (and other platforms).
-        # 
+        #
         # This may break compatibility for ultra-old perls (ones before 5.6.0)
         # so I say - Good Riddance!
         if ($^O =~ m/\AMSWin/)
@@ -2390,7 +2447,7 @@ Here's an example:
 
   use Config::IniFiles;
 
-  my %ini
+  my %ini;
   tie %ini, 'Config::IniFiles', ( -file => "/path/configfile.ini" );
 
   print "We have $ini{Section}{Parameter}." if $ini{Section}{Parameter};
@@ -2977,7 +3034,7 @@ is, if one calls
 
    $overlay->setval("section1", "arg1", "anotherval");
    $overlay->newval("section3", "arg3", "val3");
-   $overlay->WriteConfig(-delta=>1);
+   $overlay->WriteConfig('overlay.ini', -delta=>1);
 
 C<overlay.ini> would now contain
 
@@ -3004,7 +3061,7 @@ parameters like this,
 
    $overlay->DeleteSection("section2");
    $overlay->delval("section1", "arg0");
-   $overlay->WriteConfig(-delta=>1);
+   $overlay->WriteConfig('overlay.ini', -delta=>1);
 
 The I<overlay.ini> file would now read:
 
